/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"xlerror.h"
#include	"xl.h"
#include	"gbmp.h"


XL_SEXP * xl_mp_Exit();

void
init_mp_Exit(XLISP_ENV * env)
{
	set_env(env,l_string(std_cm,"Exit"),
		get_func_prim(xl_mp_Exit,FO_APPLICATIVE,0,1,1));
}

XL_SEXP *
xl_mp_Exit(XLISP_ENV * env,XL_SEXP * s)
{
/*
	wait_que_stable();
	exit_stabilizer('e');
*/
	mp_live(1);
	exit(0);
}


